Synthesis
=========

CEGIS engine, genetic algorithm, LLM clients, fitness evaluation, and
entropy monitoring.

.. automodule:: synthesis
   :members:
   :show-inheritance:

.. automodule:: synthesis.models
   :members:
   :show-inheritance:

.. automodule:: synthesis.cegis
   :members:
   :show-inheritance:

.. automodule:: synthesis.ast_operators
   :members:
   :show-inheritance:

.. automodule:: synthesis.population
   :members:
   :show-inheritance:

.. automodule:: synthesis.fitness
   :members:
   :show-inheritance:

.. automodule:: synthesis.entropy
   :members:
   :show-inheritance:

.. automodule:: synthesis.llm_client
   :members:
   :show-inheritance:

.. automodule:: synthesis.cloud_llm
   :members:
   :show-inheritance:

.. automodule:: synthesis.local_llm
   :members:
   :show-inheritance:
